/* $Header: /fridge/cvs/libjcgi/cgi-html.c,v 1.5 2001/12/10 20:42:49 justins Exp $ */
/*
   
   JCGI - cgi-html.c          Copyright(c) 2001 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   General-purpose HTML commands
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <assert.h>
#include <libjcgi.h>


void cgi_html_head_begin(const cgi_conf *c, const char *title, const char *copyright) {
/* Prints the HTML doctype, heading, and most preamble; the HEAD
   tag is NOT closed so style data may be appended.  General META
   tags which I find useful across all CGI, and common style data
   will be added here. */

   assert(c != NULL);
   assert(title != NULL);
   assert(copyright != NULL);
   
   printf("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n");
   printf("<html lang=\"en-us\">\n");
   printf("<head>\n");
   printf("<title>%s - %s</title>\n", stra(c->page_title), title);
   printf("<meta name=\"author\" content=\"Justin David Smith\">\n");
   printf("<meta name=\"copyright\" content=\"%s\">\n", copyright);
   printf("<meta name=\"MSSmartTagsPreventParsing\" content=\"TRUE\">\n");
   printf("<meta name=\"ROBOTS\" content=\"NOARCHIVE\">\n");
   printf("<meta http-equiv=\"Window-target\" content=\"_top\">\n");
   printf("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n");
   printf("<style type=\"text/css\" media=all><!--\n");
   printf("   SPAN.disable { color: %s; background-color: %s; }\n", stra(c->fg_disabled), stra(c->bg_disabled));
   printf("   SPAN.error   { color: %s; background-color: %s; }\n", stra(c->fg_error), stra(c->bg_error));
   printf("   SPAN.small   { font-size: 1em; }\n");
   printf("   SPAN.mono    { font-family: monospace; }\n");
   printf("   DIV.center   { text-align: center; }\n");
   printf("   DIV.justify, P.justify\n");
   printf("                { text-align: justify; }\n");
   printf("   A, A.noline  { text-decoration: none; color: %s; background-color: transparent; }\n", stra(c->fg_link));
   printf("   A:visited    { text-decoration: none; color: %s; background-color: transparent; }\n", stra(c->fg_visited));
   printf("   A:link:hover, A:visited:hover\n");
   printf("                { color: %s; background-color: transparent; }\n", stra(c->fg_hover));
   printf("   A:active, A:active:hover, A B:active, A I:active, A ACRONYM:active\n");             
   printf("                { color: %s; background-color: transparent; }\n", stra(c->fg_active));
   printf("   A IMG:active { border-color: %s; }\n", stra(c->fg_active));
   printf("   PRE          { font-family: monospace; }\n");
   printf("   BODY         { font-family: helvetica, arial, sans-serif; font-size: 0.833em;\n");
   printf("                  color: %s; background-color: %s; }\n", stra(c->fg_color), stra(c->bg_color));
   printf("   H1           { font-size: 1.44em; font-weight: bold; color: %s; background-color: %s; margin-right: auto; \n", stra(c->fg_head), stra(c->bg_head));
   printf("                  padding: 0.2em; border-color: %s; border-width: thin; border-style: solid; }\n", stra(c->fg_color));
   printf("   H2           { font-size: 1.2em; font-weight: bold; }\n");
   printf("   IMG.noborder { border: none; }\n");
   printf("   IMG.border   { border: thin solid; }\n");
   printf("   HR           { border-left: none; border-right: none; border-top: none; border-bottom: thin solid; height: 1pt; }\n");
   printf("   ACRONYM, ABBR\n");
   printf("                { font-style: inherit; text-decoration: inherit; }\n");
   printf("// --></style>\n");

}


void cgi_html_gpl(void) {

   printf("<p class=justify>This program is free software; you can redistribute it and/or modify it under the terms "
          "of the GNU General Public License as published by the Free Software Foundation; either "
          "version 2 of the License, or (at your option) any later version.</p>\n");
   printf("<p class=justify>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; "
          "without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. "
          "See the GNU General Public License for more details.</p>\n");
   printf("<p class=justify>You should have received a copy of the GNU General Public License along with this "
          "program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, "
          "Boston, MA  02111-1307  USA.</p>\n");

}


void cgi_html_validator_links(const cgi_env *e) {

   assert(e != NULL);

   printf("<a href=\"http://validator.w3.org./check?uri=http://%s%s\"><acronym title=\"HyperText Markup Language\">HTML</acronym>4.01 Strict</a> | ", stra(e->server_name), stra(e->request_uri));
   printf("<a href=\"http://jigsaw.w3.org/css-validator/validator?uri=http://%s%s\"><acronym title=\"Cascading Style Sheets\">CSS</acronym>2</a>", stra(e->server_name), stra(e->request_uri));

}


void cgi_html_init(const char *package, const char *version, const char *copyright) {

   assert(package != NULL);
   assert(version != NULL);
   assert(copyright != NULL);
   
   printf("content-type: text/html\n\n");
   printf("<!-- %s %s - %s -->\n\n", package, version, copyright);

}
